BonsaiError

Enum BonsaiError 

pub enum BonsaiError {
Show 13 variants InvalidMagic { magic: u32, }, UnsupportedVersion { version: u32, }, InvalidMetadata { key: String, reason: String, }, TensorNotFound { name: String, }, UnsupportedQuantType { type_id: u32, }, MmapError(Error), UnexpectedEof { offset: u64, }, AlignmentError { expected: usize, offset: u64, }, InvalidString { offset: u64, }, MissingConfigKey { key: String, }, ShapeMismatch { name: String, expected: Vec<u64>, actual: Vec<u64>, }, InvalidBlockSize { actual: usize, }, KQuantError { reason: String, },
}
Errors that can occur during GGUF parsing, tensor loading, and configuration.

Variants



InvalidMagic

Invalid GGUF magic number in file header.

Fields

magic: u32


UnsupportedVersion

Unsupported GGUF format version.

Fields

version: u32


InvalidMetadata

Invalid or missing metadata entry.

Fields

reason: String


TensorNotFound

A required tensor was not found in the model file.

Fields

name: String


UnsupportedQuantType

Unsupported quantization type encountered.

Fields

type_id: u32


MmapError(Error)

Memory mapping failed.



UnexpectedEof

Unexpected end of file during parsing.

Fields

offset: u64


AlignmentError

Data alignment error.

Fields

expected: usize
offset: u64


InvalidString

Invalid string encoding in GGUF data.

Fields

offset: u64


MissingConfigKey

A required configuration key is missing from model metadata.

Fields



ShapeMismatch

Dimension mismatch between expected and actual tensor shape.

Fields

name: String
expected: Vec<u64>
actual: Vec<u64>


InvalidBlockSize

Block size validation failed.

Fields

actual: usize


KQuantError

K-quant quantization or dequantization error.

Fields

reason: String

Implementations

Source

impl BonsaiError

pub fn error_code(&self) -> &str

Return a short, stable error code string for monitoring and alerting.

pub fn is_retryable(&self) -> bool

Whether this error is potentially recoverable by retrying.